import { ZodSchema } from 'zod';
import {} from '../Interface/ServiceInterface.js';
import {} from '../Interface/ToolInterface.js';
import { ZodSchemaValidatedService } from '../Service/ZodSchemaValidatedService.js';
/**
 * ServiceTool is a specialized class that will use a given service as a tool.
 */
export class ServiceTool extends ZodSchemaValidatedService {
    name;
    description;
    parameters;
    /**
     * Constructor.
     *
     * @param {string} name - The name of the tool
     * @param {string} description - The description of the tool
     * @param {TypePayloadSchema} payloadSchema - The Zod schema for the input data
     * @param {TypeResponseSchema} responseSchema - The Zod schema for the output data
     * @param {ServiceInterface<Infer<TypePayloadSchema>, Infer<TypeResponseSchema>>} service - The service to wrap
     */
    constructor(name, description, payloadSchema, responseSchema, service) {
        super(payloadSchema, responseSchema, service);
        this.name = name;
        this.description = description;
        this.parameters = payloadSchema;
    }
}
